# AdcircPy


#### Installation notes:

Please use a virtual environment with >=Python3.6. You may use conda or the OS's Python to provide a virtual environment for the application.
This is usually developed using the latest Python, but it should work with Python version >=3.6.

You may install the application though pip. This will install the latest tagged version.
```bash
pip install adcircpy
```


Alternatively, you many manually install the repo by cloning it and then running
```bash
pip install .
```

See the examples directory for usage examples.
